@@ -67,7 +67,7 @@ sub _generate_explicit_path {
 
 sub _generate_explicit_text {
     # non-greedily match characters that don't match the start-end delimiters
-    my $not_an_end_delimiter = '(?:(?!' . join '|', _explicit_end_delims() . ').)';  # produces (?: (?! ]] | \)\) ) .)  # a character in a place where neither a ]] nor a )) starts
+    my $not_an_end_delimiter = '(?:(?!' . ( join '|', _explicit_end_delims() ) . ').)';  # produces (?: (?! ]] | \)\) ) .)  # a character in a place where neither a ]] nor a )) starts
     return qr{$not_an_end_delimiter+?};
 }
 
@@ -210,7 +210,7 @@ we will:
 sub format_link {
 
     #FIXME: why both base and $c?
-    my ( $class, $c, $wikilink, $base, $link_text, $user_profile_wanted ) = @_;
+    my ( $class, $c, $wikilink, $base, $link_text, $action) = @_;
     $base ||= $c->req->base;
    
     # The following control structures are used to build the wikilink
@@ -306,8 +306,8 @@ sub format_link {
     if ( defined $proto_pages && @$proto_pages ) {
         my $proto_page = pop @$proto_pages;
         $url .= $proto_page->{path};
-        if ( $user_profile_wanted ) {
-            $url .= '.profile';
+        if ( $action) {
+            $url .= ".$action" ;
             return qq{<a class="existingWikiWord" href="$url">$formatted</a>};
         }
         else {
@@ -319,7 +319,7 @@ sub format_link {
     else {
         my $page = pop @$path_pages;
         $url .= $page->path;
-        $url .= '.profile' if $user_profile_wanted;
+        $url .= ".$action" if $action;
         $url .= "#$fragment" if $fragment ne '';
         return qq{<a class="existingWikiWord" href="$url">$formatted</a>};
     }
