@@ -4,9 +4,17 @@ use strict;
 use warnings;
 use parent qw/DBIx::Class/;
 
+sub sqlt_deploy_hook {
+    my ( $self, $sqlt_table ) = @_;
+    $sqlt_table->extra(
+        mysql_table_type => 'InnoDB',
+        mysql_charset    => 'utf8'
+    );
+}
+
 =head1 NAME
 
-MojoMojo::Schema::Base::Result
+MojoMojo::Schema::Base::Result - base class for Result classes
 
 =head1 DESCRIPTION
 
