@@ -11,7 +11,7 @@ use Text::Textile;
 my $textile = Text::Textile->new( flavor => "xhtml1", charset => 'utf-8' );
 
 __PACKAGE__->load_components(
-    qw/DateTime::Epoch TimeStamp EncodedColumn UTF8Columns Core/);
+    qw/DateTime::Epoch TimeStamp EncodedColumn Core/);
 __PACKAGE__->table("person");
 __PACKAGE__->add_columns(
     "id",
@@ -117,11 +117,10 @@ __PACKAGE__->has_many(
     "MojoMojo::Schema::Result::Content",
     { "foreign.creator" => "self.id" }
 );
-__PACKAGE__->utf8_columns(qw/name/);
 
 =head1 NAME
 
-MojoMojo::Schema::Result::Person
+MojoMojo::Schema::Result::Person - store user info
 
 =head1 METHODS
 
